
***********
Data Models
***********

.. _model_hpc_config:

HpcConfig
=========

.. csv-table:: 
   :file: ../build/model_tables/HpcConfig.csv
   :delim: tab

.. _model_slurm_config:

SlurmConfig
===========

.. csv-table:: 
   :file: ../build/model_tables/SlurmConfig.csv
   :delim: tab

.. _model_submitter_params:

SubmitterParams
===============

This object can be automatically generated with this command:

.. code-block:: bash

    $ jade config submitter-params

.. csv-table:: 
   :file: ../build/model_tables/SubmitterParams.csv
   :delim: tab

.. _model_submission_group:

SubmissionGroup
===============

.. csv-table:: 
   :file: ../build/model_tables/SubmissionGroup.csv
   :delim: tab
